@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "consult-vc-modified-files" "0.3.0"
+(define-package "consult-vc-modified-files" "20250724.2218"
   "Show git modified files with consult and vc."
   '((emacs   "28.1")
     (consult "0.9"))
